cvs: php4 /ext/standard basic_functions.c var.c
| From: | Derick Rethans | Date: | Thu, 28 Feb 2002 16:00:30 +0000 |
| Subject: | cvs: php4 /ext/standard basic_functions.c var.c | ||
| Groups: | php.cvs | ||
| Request: | Send a blank email to php-cvs+get-9514@lists.php.net to get a copy of this message | ||
derick Thu Feb 28 11:00:30 2002 EDT
Modified files:
/php4/ext/standard basic_functions.c var.c
Log:
- Make it a boolean
Index: php4/ext/standard/basic_functions.c
diff -u php4/ext/standard/basic_functions.c:1.445 php4/ext/standard/basic_functions.c:1.446
--- php4/ext/standard/basic_functions.c:1.445 Wed Feb 27 09:05:39 2002
+++ php4/ext/standard/basic_functions.c Thu Feb 28 11:00:26 2002
@@ -17,7 +17,7 @@
+----------------------------------------------------------------------+
*/
-/* $Id: basic_functions.c,v 1.445 2002/02/27 14:05:39 derick Exp $ */
+/* $Id: basic_functions.c,v 1.446 2002/02/28 16:00:26 derick Exp $ */
#include "php.h"
#include "php_main.h"
@@ -1869,15 +1869,15 @@
syntax_highlighter_ini->highlight_string = INI_STR("highlight.string");
}
-/* {{{ proto bool highlight_file(string file_name [, int return] )
+/* {{{ proto bool highlight_file(string file_name [, bool return] )
Syntax highlight a source file */
PHP_FUNCTION(highlight_file)
{
zval *filename;
zend_syntax_highlighter_ini syntax_highlighter_ini;
- long i = 0;
+ zend_bool i = 0;
- if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|l", &filename, &i) ==
FAILURE) {
+ if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|b", &filename, &i) ==
FAILURE) {
return;
}
convert_to_string(filename);
@@ -1901,16 +1901,16 @@
}
/* }}} */
-/* {{{ proto bool highlight_string(string string [, int return] )
+/* {{{ proto bool highlight_string(string string [, bool return] )
Syntax highlight a string or optionally return it */
PHP_FUNCTION(highlight_string)
{
zval *expr;
zend_syntax_highlighter_ini syntax_highlighter_ini;
char *hicompiled_string_description;
- long i = 0;
+ zend_bool i = 0;
- if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|l", &expr, &i) ==
FAILURE) {
+ if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|b", &expr, &i) ==
FAILURE) {
return;
}
convert_to_string(expr);
Index: php4/ext/standard/var.c
diff -u php4/ext/standard/var.c:1.129 php4/ext/standard/var.c:1.130
--- php4/ext/standard/var.c:1.129 Sun Feb 24 09:07:10 2002
+++ php4/ext/standard/var.c Thu Feb 28 11:00:26 2002
@@ -304,14 +304,14 @@
/* }}} */
/* {{{ proto mixed var_export(mixed var [, int return])
Outputs or returns a string representation of avariable */
PHP_FUNCTION(var_export)
{
zval *var;
- long i = 0;
+ zend_bool i = 0;
- if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|l", &var, &i) ==
FAILURE) {
+ if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|b", &var, &i) ==
FAILURE) {
return;
}
@@ -304,14 +304,14 @@
/* }}} */
-/* {{{ proto mixed var_export(mixed var [, int return])
+/* {{{ proto mixed var_export(mixed var [, bool return])
Outputs or returns a string representation of avariable */
PHP_FUNCTION(var_export)